# coding=utf-8
from .models import DeviceModel
from .serializers import DeviceSerializer
from utils.exceptions import CustomError
from utils.permission import IsTenantUser
from .filters import DeviceFilter
from utils.custom_modelviewset import CustomModelViewSet
from apps.log.models import BizLog
from apps.tenant import tenant_log

# Create your views here.
class DeviceViewSet(CustomModelViewSet):
    permission_classes = [IsTenantUser]
    queryset = DeviceModel.objects.all()
    serializer_class = DeviceSerializer

    def filter_queryset(self, queryset):
        queryset = queryset.filter(tenant=self.request.user.employee.tenant)
        f = DeviceFilter(self.request.GET, queryset=queryset)
        return f.qs

    def perfrom_create(self, serializer):
        super(DeviceViewSet, self).perform_create(serializer)
        instance = serializer.instance
        validated_data = serializer.validated_data
        tenant_log(self.request.user.employee, BizLog.INSERT, u'添加设备信息[%s]，id=%d' % (instance.name, instance.id),
                   validated_data)

    def perform_update(self, serializer):
        #更新
        super(DeviceViewSet, self).perform_update(serializer)
        instance = serializer.instance
        validated_data = serializer.validated_data
        tenant_log(self.request.user.employee, BizLog.INSERT, u'修改设备信息[%s]，id=%d' % (instance.name, instance.id),
                   validated_data)

    def perform_destroy(self, instance):
        #删除
        if instance.tenant != self.request.user.employee.tenant:
            raise CustomError(u'禁止跨租户操作！')
        tenant_log(self.request.user.employee, BizLog.DELETE, u'删除设备信息[%s]，id=%d' % (instance.name, instance.id))
        super(DeviceViewSet, self).perform_destroy(instance)
